@@ -43,7 +43,6 @@
 #include "powerdeviladaptor.h"
 #include "PollSystemLoader.h"
 #include "SuspensionLockHandler.h"
-#include "AbstractSystemPoller.h"
 
 #include <solid/device.h>
 #include <solid/deviceinterface.h>
@@ -54,7 +53,6 @@
 #include "ksmserver_interface.h"
 
 #include <config-powerdevil.h>
-#include <config-workspace.h>
 
 #ifdef HAVE_DPMS
 #include <X11/Xmd.h>
@@ -172,8 +170,6 @@ PowerDevilDaemon::PowerDevilDaemon(QObject *parent, const QList<QVariant>&)
      * let's check what we got.
      */
 
-    m_pollLoader->createAvailableCache();
-
     if (PowerDevilSettings::pollingSystem() == -1) {
         // Ok, new configuration... so let's see what we've got!!
 
@@ -208,27 +204,58 @@ PowerDevilDaemon::~PowerDevilDaemon()
 }
 
 void PowerDevilDaemon::setUpPollingSystem()
+{
+    if (!loadPollingSystem((AbstractSystemPoller::PollingType) PowerDevilSettings::pollingSystem())) {
+        /* Let's try to load each profile one at a time, and then
+         * set the configuration to the profile that worked out.
+         */
+
+        if (loadPollingSystem(AbstractSystemPoller::XSyncBased)) {
+            PowerDevilSettings::setPollingSystem(AbstractSystemPoller::XSyncBased);
+            PowerDevilSettings::self()->writeConfig();
+            return;
+        }
+
+        if (loadPollingSystem(AbstractSystemPoller::WidgetBased)) {
+            PowerDevilSettings::setPollingSystem(AbstractSystemPoller::WidgetBased);
+            PowerDevilSettings::self()->writeConfig();
+            return;
+        }
+
+        if (loadPollingSystem(AbstractSystemPoller::TimerBased)) {
+            PowerDevilSettings::setPollingSystem(AbstractSystemPoller::TimerBased);
+            PowerDevilSettings::self()->writeConfig();
+            return;
+        }
+
+        /* If we're here, we have a big problem, since no polling system has been loaded.
+         * What should we do? For now, let's just spit out a kError
+         */
+
+        kError() << "Could not load a polling system!";
+    }
+}
+
+bool PowerDevilDaemon::loadPollingSystem(AbstractSystemPoller::PollingType type)
 {
     QMap<AbstractSystemPoller::PollingType, QString> pList = m_pollLoader->getAvailableSystems();
 
-    if (!pList.contains((AbstractSystemPoller::PollingType) PowerDevilSettings::pollingSystem())) {
-        m_pollLoader->loadSystem(AbstractSystemPoller::TimerBased);
-        PowerDevilSettings::setPollingSystem((int) AbstractSystemPoller::TimerBased);
-        PowerDevilSettings::self()->writeConfig();
+    if (!pList.contains(type)) {
+        return false;
     } else {
-        m_pollLoader->loadSystem((AbstractSystemPoller::PollingType) PowerDevilSettings::pollingSystem());
+        if (!m_pollLoader->loadSystem(type)) {
+            return false;
+        }
     }
 
     if (m_pollLoader->poller()) {
         connect(m_pollLoader->poller(), SIGNAL(resumingFromIdle()), SLOT(resumeFromIdle()));
         connect(m_pollLoader->poller(), SIGNAL(pollRequest(int)), SLOT(poll(int)));
     } else {
-        m_pollLoader->loadSystem(AbstractSystemPoller::TimerBased);
-        PowerDevilSettings::setPollingSystem((int) AbstractSystemPoller::TimerBased);
-        PowerDevilSettings::self()->writeConfig();
-        connect(m_pollLoader->poller(), SIGNAL(resumingFromIdle()), SLOT(resumeFromIdle()));
-        connect(m_pollLoader->poller(), SIGNAL(pollRequest(int)), SLOT(poll(int)));
+        return false;
     }
+
+    return true;
 }
 
 QVariantMap PowerDevilDaemon::getSupportedPollingSystems()
@@ -375,9 +402,21 @@ void PowerDevilDaemon::setUpDPMS()
 
         //
 
-        DPMSSetTimeouts(dpy, 60 * settings->readEntry("DPMSStandby").toInt(),
-                        60 * settings->readEntry("DPMSSuspend").toInt(),
-                        60 * settings->readEntry("DPMSPowerOff").toInt());
+        int standby = 60 * settings->readEntry("DPMSStandby").toInt();
+        int suspend = 60 * settings->readEntry("DPMSSuspend").toInt();
+        int poff = 60 * settings->readEntry("DPMSPowerOff").toInt();
+
+        if (settings->readEntry("DPMSStandbyEnabled", false)) {
+            standby = 0;
+        }
+        if (settings->readEntry("DPMSSuspendEnabled", false)) {
+            suspend = 0;
+        }
+        if (settings->readEntry("DPMSPowerOffEnabled", false)) {
+            poff = 0;
+        }
+
+        DPMSSetTimeouts(dpy, standby, suspend, poff);
 
         XFlush(dpy);
         XSetErrorHandler(defaultHandler);
@@ -482,16 +521,16 @@ void PowerDevilDaemon::buttonPressed(int but)
 
         switch (settings->readEntry("lidAction").toInt()) {
         case Shutdown:
-            shutdownNotification();
+            shutdownNotification(true);
             break;
         case S2Disk:
-            suspendToDiskNotification();
+            suspendToDiskNotification(true);
             break;
         case S2Ram:
-            suspendToRamNotification();
+            suspendToRamNotification(true);
             break;
         case Standby:
-            standbyNotification();
+            standbyNotification(true);
             break;
         case Lock:
             lockScreen();
@@ -572,9 +611,9 @@ void PowerDevilDaemon::increaseBrightness()
     Solid::Control::PowerManager::setBrightness(currentBrightness);
 }
 
-void PowerDevilDaemon::shutdownNotification()
+void PowerDevilDaemon::shutdownNotification(bool automated)
 {
-    if (!m_lockHandler->setNotificationLock()) {
+    if (!m_lockHandler->setNotificationLock(automated)) {
         return;
     }
 
@@ -588,9 +627,9 @@ void PowerDevilDaemon::shutdownNotification()
     }
 }
 
-void PowerDevilDaemon::suspendToDiskNotification()
+void PowerDevilDaemon::suspendToDiskNotification(bool automated)
 {
-    if (!m_lockHandler->setNotificationLock()) {
+    if (!m_lockHandler->setNotificationLock(automated)) {
         return;
     }
 
@@ -604,9 +643,9 @@ void PowerDevilDaemon::suspendToDiskNotification()
     }
 }
 
-void PowerDevilDaemon::suspendToRamNotification()
+void PowerDevilDaemon::suspendToRamNotification(bool automated)
 {
-    if (!m_lockHandler->setNotificationLock()) {
+    if (!m_lockHandler->setNotificationLock(automated)) {
         return;
     }
 
@@ -620,9 +659,9 @@ void PowerDevilDaemon::suspendToRamNotification()
     }
 }
 
-void PowerDevilDaemon::standbyNotification()
+void PowerDevilDaemon::standbyNotification(bool automated)
 {
-    if (!m_lockHandler->setNotificationLock()) {
+    if (!m_lockHandler->setNotificationLock(automated)) {
         return;
     }
 
@@ -636,9 +675,9 @@ void PowerDevilDaemon::standbyNotification()
     }
 }
 
-void PowerDevilDaemon::shutdown()
+void PowerDevilDaemon::shutdown(bool automated)
 {
-    if (!m_lockHandler->setJobLock()) {
+    if (!m_lockHandler->setJobLock(automated)) {
         return;
     }
 
@@ -654,9 +693,9 @@ void PowerDevilDaemon::shutdownDialog()
                              (int)KWorkSpace::ShutdownModeDefault);
 }
 
-void PowerDevilDaemon::suspendToDisk()
+void PowerDevilDaemon::suspendToDisk(bool automated)
 {
-    if (!m_lockHandler->setJobLock()) {
+    if (!m_lockHandler->setJobLock(automated)) {
         return;
     }
 
@@ -667,16 +706,16 @@ void PowerDevilDaemon::suspendToDisk()
     }
 
     KJob * job = Solid::Control::PowerManager::suspend(Solid::Control::PowerManager::ToDisk);
-    connect(job, SIGNAL(finished(KJob *)), this, SLOT(suspendJobResult(KJob *)));
+    connect(job, SIGNAL(result(KJob *)), this, SLOT(suspendJobResult(KJob *)));
     job->start();
 
     // Temporary hack...
     QTimer::singleShot(10000, m_lockHandler, SLOT(releaseAllLocks()));
 }
 
-void PowerDevilDaemon::suspendToRam()
+void PowerDevilDaemon::suspendToRam(bool automated)
 {
-    if (!m_lockHandler->setJobLock()) {
+    if (!m_lockHandler->setJobLock(automated)) {
         return;
     }
 
@@ -687,15 +726,15 @@ void PowerDevilDaemon::suspendToRam()
     }
 
     KJob * job = Solid::Control::PowerManager::suspend(Solid::Control::PowerManager::ToRam);
-    connect(job, SIGNAL(finished(KJob *)), this, SLOT(suspendJobResult(KJob *)));
+    connect(job, SIGNAL(result(KJob *)), this, SLOT(suspendJobResult(KJob *)));
     job->start();
     // Temporary hack...
     QTimer::singleShot(10000, m_lockHandler, SLOT(releaseAllLocks()));
 }
 
-void PowerDevilDaemon::standby()
+void PowerDevilDaemon::standby(bool automated)
 {
-    if (!m_lockHandler->setJobLock()) {
+    if (!m_lockHandler->setJobLock(automated)) {
         return;
     }
 
@@ -706,7 +745,7 @@ void PowerDevilDaemon::standby()
     }
 
     KJob * job = Solid::Control::PowerManager::suspend(Solid::Control::PowerManager::Standby);
-    connect(job, SIGNAL(finished(KJob *)), this, SLOT(suspendJobResult(KJob *)));
+    connect(job, SIGNAL(result(KJob *)), this, SLOT(suspendJobResult(KJob *)));
     job->start();
 
     // Temporary hack...
@@ -745,14 +784,14 @@ void PowerDevilDaemon::poll(int idle)
         return;
     }
 
-    if (!PowerDevilSettings::dimOnIdle() && !settings->readEntry("turnOffIdle", false) &&
+    if (!settings->readEntry("dimOnIdle", false) && !settings->readEntry("turnOffIdle", false) &&
             settings->readEntry("idleAction").toInt() == None) {
         kDebug() << "Stopping timer";
         m_pollLoader->poller()->stopCatchingTimeouts();
         return;
     }
 
-    int dimOnIdleTime = PowerDevilSettings::dimOnIdleTime() * 60;
+    int dimOnIdleTime = settings->readEntry("dimOnIdleTime").toInt() * 60;
     int minDimTime = dimOnIdleTime * 1 / 2;
     int minDimEvent = dimOnIdleTime;
 
@@ -765,10 +804,10 @@ void PowerDevilDaemon::poll(int idle)
 
     int minTime = settings->readEntry("idleTime").toInt() * 60;
 
-    if (settings->readEntry("turnOffIdle", QVariant()).toBool()) {
+    if (settings->readEntry("turnOffIdle", false)) {
         minTime = qMin(minTime, settings->readEntry("turnOffIdleTime").toInt() * 60);
     }
-    if (PowerDevilSettings::dimOnIdle()) {
+    if (settings->readEntry("dimOnIdle", false)) {
         minTime = qMin(minTime, minDimTime);
     }
 
@@ -795,19 +834,19 @@ void PowerDevilDaemon::poll(int idle)
         switch (settings->readEntry("idleAction").toInt()) {
         case Shutdown:
             m_pollLoader->poller()->catchIdleEvent();
-            shutdownNotification();
+            shutdownNotification(true);
             break;
         case S2Disk:
             m_pollLoader->poller()->catchIdleEvent();
-            suspendToDiskNotification();
+            suspendToDiskNotification(true);
             break;
         case S2Ram:
             m_pollLoader->poller()->catchIdleEvent();
-            suspendToRamNotification();
+            suspendToRamNotification(true);
             break;
         case Standby:
             m_pollLoader->poller()->catchIdleEvent();
-            standbyNotification();
+            standbyNotification(true);
             break;
         case Lock:
             m_pollLoader->poller()->catchIdleEvent();
@@ -819,16 +858,16 @@ void PowerDevilDaemon::poll(int idle)
 
         return;
 
-    } else if (PowerDevilSettings::dimOnIdle()
+    } else if (settings->readEntry("dimOnIdle", false)
                && (idle >= dimOnIdleTime)) {
         m_pollLoader->poller()->catchIdleEvent();
         Solid::Control::PowerManager::setBrightness(0);
-    } else if (PowerDevilSettings::dimOnIdle()
+    } else if (settings->readEntry("dimOnIdle", false)
                && (idle >= (dimOnIdleTime * 3 / 4))) {
         m_pollLoader->poller()->catchIdleEvent();
         float newBrightness = Solid::Control::PowerManager::brightness() / 4;
         Solid::Control::PowerManager::setBrightness(newBrightness);
-    } else if (PowerDevilSettings::dimOnIdle() &&
+    } else if (settings->readEntry("dimOnIdle", false) &&
                (idle >= (dimOnIdleTime * 1 / 2))) {
         m_pollLoader->poller()->catchIdleEvent();
         float newBrightness = Solid::Control::PowerManager::brightness() / 2;
@@ -854,7 +893,7 @@ void PowerDevilDaemon::setUpNextTimeout(int idle, int minDimEvent)
             nextTimeout = (settings->readEntry("idleTime").toInt() * 60) - idle;
         }
     }
-    if (minDimEvent > idle && PowerDevilSettings::dimOnIdle()) {
+    if (minDimEvent > idle && settings->readEntry("dimOnIdle", false)) {
         if (nextTimeout >= 0) {
             nextTimeout = qMin(nextTimeout, minDimEvent - idle);
         } else {
@@ -1223,7 +1262,9 @@ void PowerDevilDaemon::profileFirstLoad()
         m_compositingChanged = false;
     }
 
-    QTimer::singleShot(300, this, SLOT(setUpDPMS()));
+    if (PowerDevilSettings::manageDPMS()) {
+        QTimer::singleShot(300, this, SLOT(setUpDPMS()));
+    }
 }
 
 bool PowerDevilDaemon::toggleCompositing(bool enabled)
