@@ -26,6 +26,8 @@
 #include <KComponentData>
 #include <QStringList>
 
+#include "AbstractSystemPoller.h"
+
 class QWidget;
 class QTimer;
 class PollSystemLoader;
@@ -38,6 +40,7 @@ class OrgKdeScreensaverInterface;
 class KDE_EXPORT PowerDevilDaemon : public KDEDModule
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.kde.PowerDevil")
 
 public:
     PowerDevilDaemon(QObject *parent, const QList<QVariant>&);
@@ -81,17 +84,17 @@ private Q_SLOTS:
     void decreaseBrightness();
     void increaseBrightness();
 
-    void shutdown();
+    void shutdown(bool automated = false);
     void shutdownDialog();
     void suspendJobResult(KJob * job);
-    void suspendToDisk();
-    void suspendToRam();
-    void standby();
+    void suspendToDisk(bool automated = false);
+    void suspendToRam(bool automated = false);
+    void standby(bool automated = false);
 
-    void shutdownNotification();
-    void suspendToDiskNotification();
-    void suspendToRamNotification();
-    void standbyNotification();
+    void shutdownNotification(bool automated = false);
+    void suspendToDiskNotification(bool automated = false);
+    void suspendToRamNotification(bool automated = false);
+    void standbyNotification(bool automated = false);
 
     void buttonPressed(int but);
 
@@ -136,6 +139,8 @@ private:
 
     void restoreDefaultProfiles();
 
+    bool loadPollingSystem(AbstractSystemPoller::PollingType type);
+
 public:
     enum IdleAction {
         None = 0,
